# Streamlit 簡易アプリの要件定義書
## ゴール: {prompt} に関するStreamlitの簡易アプリをローカルに作る
上記のゴールを満たす超最低限のStreamlitアプリケーションの要件を記述する
## 1. 目的
## 2. 環境構築方法
- 実行コードレベルで記載してください（コードはコードブロックに入れる）
- 仮想環境は立ち上げて欲しい（streamlit_mini）
## 3. 実行方法
- 実行コードレベルで記載してください（コードはコードブロックに入れる）
## 4. ファイル・フォルダ構成

**以下のみ**
.
├── README.md
├── app
    └── app.py（これは詳細に記載）
